# PeerReviewGroupV30Rc1

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**last_modified_date** | [**LastModifiedDateV30Rc1**](LastModifiedDateV30Rc1.md) |  | [optional] 
**external_ids** | [**ExternalIDsV30Rc1**](ExternalIDsV30Rc1.md) |  | [optional] 
**peer_review_group** | [**list[PeerReviewDuplicateGroupV30Rc1]**](PeerReviewDuplicateGroupV30Rc1.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

